/* This file is part of mailfrom filter.
   Copyright (C) 2005, Sergey Poznyakoff

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
   MA 02110-1301 USA */

#ifndef MAXPACKET
# define MAXPACKET 8192	/* max packet size used internally by BIND */
#endif 

typedef enum {
	getmx_success,
	getmx_not_found,
	getmx_failure,
	getmx_temp_failure,
} getmx_status;

#define getmx_resolved(c) ((c) == getmx_success || (c) == getmx_not_found)

#define MAXMXCOUNT 32
typedef char *mxbuf_t[MAXMXCOUNT];

#define DEFAULT_PIDFILE MAILFROMSTATEDIR "/mailfromd.pid"
#define DEFAULT_DATABASE MAILFROMSTATEDIR "/mailfromd"

#define debug(lev,c) do if (debug_level >= lev) {\
 debug_log("%s:%lu:%s: ", __FILE__, __LINE__, __FUNCTION__); \
 debug_log c; \
} while (0)

extern int debug_level;
extern time_t expire_interval;

extern getmx_status getmx(char *ipstr, mxbuf_t mxbuf);

#include "mu_dbm.h"

#ifdef USE_DBM
# define cache_get _mailfrom_cache_get
# define cache_insert _mailfrom_cache_insert
# define cache_get2 _mailfrom_cache_get2
# define cache_insert2 _mailfrom_cache_insert2
# define cache_delete _mailfrom_cache_delete
# define cache_list_item _mailfrom_cache_list_item
# define cache_list_db _mailfrom_cache_list_db
# define cache_expire_db _mailfrom_cache_expire_db
getmx_status cache_get(char *email);
void cache_insert(char *email, getmx_status rc);
void cache_delete(char *email);
getmx_status cache_get2(char *email, char *client_addr);
void cache_insert2(char *email, char *client_addr, getmx_status rc);
void cache_list_item(char *email);
void cache_list_db(void);
void cache_expire_db(void);
#else
# define cache_get(email) getmx_failure
# define cache_insert(email, rc)
# define cache_get2(email, client_addr) getmx_failure
# define cache_insert2(email, client_addr, rc)
# define cache_delete(email)
# define cache_list_item(email)
# define cache_list_db()
# define cache_expire_db()
#endif


